warn_unsupported

Function warn_unsupported 

pub fn warn_unsupported(service_name: &str)
Emit a one-shot warning that a given service does not yet honor PersistenceConfig and will continue to run purely in memory.